@@ -1,6 +1,6 @@
 from rest_framework import serializers
 
-from netbox.api import WritableNestedSerializer
+from netbox.api.serializers import WritableNestedSerializer
 from netbox_secretstore.models import Secret, SecretRole
 
 __all__ = [
