@@ -10,13 +10,13 @@ menu_items = (
                 link="plugins:netbox_secretstore:secretrole_add",
                 title="Add Secret Role",
                 icon_class="mdi mdi-plus-thick",
-                color="success",
+                color="green",
             ),
             PluginMenuButton(
                 link="plugins:netbox_secretstore:secretrole_import",
                 title="Import Secret Role",
                 icon_class="mdi mdi-upload",
-                color="info",
+                color="teal",
             ),
         ),
     ),
@@ -28,13 +28,13 @@ menu_items = (
                 link="plugins:netbox_secretstore:secret_add",
                 title="Add Secret",
                 icon_class="mdi mdi-plus-thick",
-                color="success",
+                color="green",
             ),
             PluginMenuButton(
                 link="plugins:netbox_secretstore:secret_import",
                 title="Import Secret",
                 icon_class="mdi mdi-upload",
-                color="info",
+                color="teal",
             ),
         ),
     ),
