@@ -1,10 +1,11 @@
 from django.test import TestCase
 
 from dcim.models import Device, DeviceRole, DeviceType, Manufacturer, Site
-from netbox_secretstore.filters import *
-from models import Secret, SecretRole
 from virtualization.models import Cluster, ClusterType, VirtualMachine
 
+from netbox_secretstore.filtersets import *
+from netbox_secretstore.models import Secret, SecretRole
+
 
 class SecretRoleTestCase(TestCase):
     queryset = SecretRole.objects.all()
